import type { Errors, FormDataConvertible, FormDataKeys, Method, Progress, VisitOptions } from '@inertiajs/core';
import { type Writable } from 'svelte/store';
type FormDataType = Record<string, FormDataConvertible>;
type FormOptions = Omit<VisitOptions, 'data'>;
export interface InertiaFormProps<TForm extends FormDataType> {
    isDirty: boolean;
    errors: Partial<Record<FormDataKeys<TForm>, string>>;
    hasErrors: boolean;
    progress: Progress | null;
    wasSuccessful: boolean;
    recentlySuccessful: boolean;
    processing: boolean;
    setStore(data: TForm): void;
    setStore(key: FormDataKeys<TForm>, value?: FormDataConvertible): void;
    data(): TForm;
    transform(callback: (data: TForm) => object): this;
    defaults(): this;
    defaults(fields: Partial<TForm>): this;
    defaults(field?: FormDataKeys<TForm>, value?: FormDataConvertible): this;
    reset(...fields: FormDataKeys<TForm>[]): this;
    clearErrors(...fields: FormDataKeys<TForm>[]): this;
    setError(field: FormDataKeys<TForm>, value: string): this;
    setError(errors: Errors): this;
    submit: (...args: [Method, string, FormOptions?] | [{
        url: string;
        method: Method;
    }, FormOptions?]) => void;
    get(url: string, options?: FormOptions): void;
    post(url: string, options?: FormOptions): void;
    put(url: string, options?: FormOptions): void;
    patch(url: string, options?: FormOptions): void;
    delete(url: string, options?: FormOptions): void;
    cancel(): void;
}
export type InertiaForm<TForm extends FormDataType> = InertiaFormProps<TForm> & TForm;
export default function useForm<TForm extends FormDataType>(data: TForm | (() => TForm)): Writable<InertiaForm<TForm>>;
export default function useForm<TForm extends FormDataType>(rememberKey: string, data: TForm | (() => TForm)): Writable<InertiaForm<TForm>>;
export {};
